# python-mobilealerts

[![Build status](https://github.com/PlusPlus-ua/python-mobilealerts/workflows/build/badge.svg?branch=master&event=push)](https://github.com/PlusPlus-ua/python-mobilealerts/actions?query=workflow%3Abuild) [![Python Version](https://img.shields.io/pypi/pyversions/python-mobilealerts.svg)](https://pypi.org/project/python-mobilealerts/) [![Dependencies Status](https://img.shields.io/badge/dependencies-up%20to%20date-brightgreen.svg)](https://github.com/PlusPlus-ua/python-mobilealerts/pulls?utf8=%E2%9C%93&q=is%3Apr%20author%3Aapp%2Fdependabot) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Security: bandit](https://img.shields.io/badge/security-bandit-green.svg)](https://github.com/PyCQA/bandit) [![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/PlusPlus-ua/python-mobilealerts/blob/master/.pre-commit-config.yaml) [![Semantic Versions](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--versions-e10079.svg)](https://github.com/PlusPlus-ua/python-mobilealerts/releases) [![License](https://img.shields.io/github/license/PlusPlus-ua/python-mobilealerts)](https://github.com/PlusPlus-ua/python-mobilealerts/blob/master/LICENSE)


## Python classes for MobileAlerts gateway and sensors

Library act as proxy server which intercepts all measurements and sensors properties which sends MobileAlerts gateway to the cloud. 

Everything works in asynchronous way in order to build on the base of this library [Home assistant](https://github.com/home-assistant/core) integration.

## Installation

```bash
pip install -U python-mobilealerts
```

or install with `Poetry`

```bash
poetry add python-mobilealerts
```

## 🛡 License

[![License](https://img.shields.io/github/license/PlusPlus-ua/python-mobilealerts)](https://github.com/PlusPlus-ua/python-mobilealerts/blob/master/LICENSE)

This project is licensed under the terms of the `MIT` license. See [LICENSE](https://github.com/PlusPlus-ua/python-mobilealerts/blob/master/LICENSE) for more details.

## Credits

This project was inspired and developed on the base of [MMMMobileAlerts](https://github.com/sarnau/MMMMobileAlerts)

This project was generated with [python-package-template](https://github.com/TezRomacH/python-package-template)
